==> qtjambi-qt3dinput-debuginfo-macos-5.15.17.jar: sources/QtJambi3DInput/QPhysicalDeviceCreatedChangeBase_shell.cpp <==
#include "QPhysicalDeviceCreatedChangeBase_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DInput::QPhysicalDeviceCreatedChangeBase")
    Qt3DInput::QPhysicalDeviceCreatedChangeBase *_ptr = reinterpret_cast<Qt3DInput::QPhysicalDeviceCreatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPhysicalDeviceCreatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPhysicalDeviceCreatedChangeBase_shell) ); }

jmethodID QPhysicalDeviceCreatedChangeBase_shell::__shell_javaMethod(int pos) const { return QPhysicalDeviceCreatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase), pos); }

// emitting (writeShellConstructor)
QPhysicalDeviceCreatedChangeBase_shell::QPhysicalDeviceCreatedChangeBase_shell(const Qt3DInput::QAbstractPhysicalDevice* device0)
    : Qt3DInput::QPhysicalDeviceCreatedChangeBase(device0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase_shell(const Qt3DInput::QAbstractPhysicalDevice* device0)", QPhysicalDeviceCreatedChangeBase_shell::__shell())
    QPhysicalDeviceCreatedChangeBase_shell::__shell()->constructed(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

// emitting (writeShellDestructor)
QPhysicalDeviceCreatedChangeBase_shell::~QPhysicalDeviceCreatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::~Qt3DInput::QPhysicalDeviceCreatedChangeBase()", QPhysicalDeviceCreatedChangeBase_shell::__shell())
    QPhysicalDeviceCreatedChangeBase_shell::__shell()->destructed(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

void QPhysicalDeviceCreatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPhysicalDeviceCreatedChangeBase_shell*>(ptr)->QPhysicalDeviceCreatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)
void __qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)")
    jobject device0 = __java_arguments[0].l;
    const Qt3DInput::QAbstractPhysicalDevice* __qt_device0 = qtjambi_cast<const Qt3DInput::QAbstractPhysicalDevice* >(__jni_env, device0);
    Qt3DInput::QPhysicalDeviceCreatedChangeBase *__qt_this = new(__qtjambi_ptr) QPhysicalDeviceCreatedChangeBase_shell(__qt_device0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPhysicalDeviceCreatedChangeBase_shell
void __qt_destruct_Qt3DInput_QPhysicalDeviceCreatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DInput::QPhysicalDeviceCreatedChangeBase")
    reinterpret_cast<QPhysicalDeviceCreatedChangeBase_shell*>(ptr)->~QPhysicalDeviceCreatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_initialize_1native__Lio_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_2Lio_qt_qt3d_input_QAbstractPhysicalDevice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject device0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = device0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_0, sizeof(QPhysicalDeviceCreatedChangeBase_shell), typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase), true, &deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DInput::QPhysicalDeviceCreatedChangeBase::axisSettingIds()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_axisSettingIds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DInput::QPhysicalDeviceCreatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DInput::QPhysicalDeviceCreatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::axisSettingIds()const", __qt_this)
        QVector<Qt3DCore::QNodeId> __qt_return_value = __qt_this->axisSettingIds();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DInput_QPhysicalDeviceCreatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DInput::QPhysicalDeviceCreatedChangeBase>("Qt3DInput::QPhysicalDeviceCreatedChangeBase", "io/qt/qt3d/input/QPhysicalDeviceCreatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DInput_QPhysicalDeviceCreatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_0, "Lio/qt/qt3d/input/QAbstractPhysicalDevice;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPhysicalDeviceCreatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QNodeCreatedChangeBase, Qt3DInput::QPhysicalDeviceCreatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dinput-debuginfo-macos-5.15.20.jar: sources/QtJambi3DInput/QPhysicalDeviceCreatedChangeBase_shell.cpp <==
#include "QPhysicalDeviceCreatedChangeBase_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DInput::QPhysicalDeviceCreatedChangeBase")
    Qt3DInput::QPhysicalDeviceCreatedChangeBase *_ptr = reinterpret_cast<Qt3DInput::QPhysicalDeviceCreatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPhysicalDeviceCreatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPhysicalDeviceCreatedChangeBase_shell) ); }

jmethodID QPhysicalDeviceCreatedChangeBase_shell::__shell_javaMethod(int pos) const { return QPhysicalDeviceCreatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase), pos); }

// emitting (writeShellConstructor)
QPhysicalDeviceCreatedChangeBase_shell::QPhysicalDeviceCreatedChangeBase_shell(const Qt3DInput::QAbstractPhysicalDevice* device0)
    : Qt3DInput::QPhysicalDeviceCreatedChangeBase(device0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase_shell(const Qt3DInput::QAbstractPhysicalDevice* device0)", QPhysicalDeviceCreatedChangeBase_shell::__shell())
    QPhysicalDeviceCreatedChangeBase_shell::__shell()->constructed(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

// emitting (writeShellDestructor)
QPhysicalDeviceCreatedChangeBase_shell::~QPhysicalDeviceCreatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::~Qt3DInput::QPhysicalDeviceCreatedChangeBase()", QPhysicalDeviceCreatedChangeBase_shell::__shell())
    QPhysicalDeviceCreatedChangeBase_shell::__shell()->destructed(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

void QPhysicalDeviceCreatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPhysicalDeviceCreatedChangeBase_shell*>(ptr)->QPhysicalDeviceCreatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)
void __qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_const_Qt3DInput_QAbstractPhysicalDevice_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)")
    jobject device0 = __java_arguments[0].l;
    const Qt3DInput::QAbstractPhysicalDevice* __qt_device0 = qtjambi_cast<const Qt3DInput::QAbstractPhysicalDevice* >(__jni_env, device0);
    Qt3DInput::QPhysicalDeviceCreatedChangeBase *__qt_this = new(__qtjambi_ptr) QPhysicalDeviceCreatedChangeBase_shell(__qt_device0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_initialize_1native__Lio_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_2Lio_qt_qt3d_input_QAbstractPhysicalDevice_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject device0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::QPhysicalDeviceCreatedChangeBase(const Qt3DInput::QAbstractPhysicalDevice*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = device0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_const_Qt3DInput_QAbstractPhysicalDevice_ptr, sizeof(QPhysicalDeviceCreatedChangeBase_shell), typeid(Qt3DInput::QPhysicalDeviceCreatedChangeBase), true, &deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPhysicalDeviceCreatedChangeBase_shell
void __qt_destruct_Qt3DInput_QPhysicalDeviceCreatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DInput::QPhysicalDeviceCreatedChangeBase")
    reinterpret_cast<QPhysicalDeviceCreatedChangeBase_shell*>(ptr)->~QPhysicalDeviceCreatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DInput::QPhysicalDeviceCreatedChangeBase::axisSettingIds()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_input_QPhysicalDeviceCreatedChangeBase_axisSettingIds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DInput::QPhysicalDeviceCreatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DInput::QPhysicalDeviceCreatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DInput::QPhysicalDeviceCreatedChangeBase::axisSettingIds()const", __qt_this)
        QVector<Qt3DCore::QNodeId> __qt_return_value = __qt_this->axisSettingIds();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DInput_QPhysicalDeviceCreatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DInput::QPhysicalDeviceCreatedChangeBase>("Qt3DInput::QPhysicalDeviceCreatedChangeBase", "io/qt/qt3d/input/QPhysicalDeviceCreatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DInput_QPhysicalDeviceCreatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DInput_QPhysicalDeviceCreatedChangeBase_const_Qt3DInput_QAbstractPhysicalDevice_ptr, "Lio/qt/qt3d/input/QAbstractPhysicalDevice;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DInput_QPhysicalDeviceCreatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPhysicalDeviceCreatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QNodeCreatedChangeBase, Qt3DInput::QPhysicalDeviceCreatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
